/* $Id: option.h,v 1.4 1998/03/11 02:36:22 scott Exp $ */

/* This is a structure for describing the type of derivative we are
 * dealing with.  Right now, it is written for a max option so it is
 * pretty close to empty.  The payoff of a max option on n underliers
 * is max(S_1, S_2, ... S_n) - K, where S_i are the underlier prices 
 * and K is the strike price.
 */

typedef struct{
  /* Public. These should be used outside the option* files.
   *
   * strikePrice                The strikePrice.
   *
   * pData                      A pathData structure containing describing the
   *                            underliers that this option depends on.
   * params             An optionParams structure describing the option
   *                    and its underliers.
   *
   * payoff             Payoff[t][p] is the payoff of the option for the
   *                    prices at time t on path p.
   *
   * euroPrice          euroPrice[t][p] is the payoff of the european option
   *                    starting at time t and path p with a maturity of 1
   *                    period.
   *
   * euroChoice         euroChoice[t][p] is the underlier which is exercised
   *                    to give the price in euroPrice[t][p]
   *
   */

  double strikePrice;
  pathData pData;
  double **payoff;
  double riskFreeRate;
  double **euroPrice;
  int **euroChoice;
}optionData;


void optionDataAllocate(optionData *od);
double optionPayoff(optionData *op, double *price);
void optionPayoffFillArray(pathData *pd, optionData *od, double **payoffArray);
void optionDataFill(optionData *od);
void optionDataDeallocate(optionData *od);

